@@ -1,5 +1,6 @@
 import struct
 
+from ptpip.constants.packet_type import PacketType
 from ptpip.constants.data_object_transfer_mode import DataObjectTransferMode
 
 from ptpip.data_object.data_object import DataObject
@@ -16,7 +17,7 @@ class Ping(Packet):
         dataObjectTransferMode: DataObjectTransferMode = None
     ):
         super(Ping, self).__init__(
-            13,
+            PacketType.Ping,
             data = data,
             transactionId = transactionId,
             dataObject = dataObject,
@@ -25,10 +26,10 @@ class Ping(Packet):
 
     def pack(self):
         return StreamWriter() \
-            .writeUint32(self.cmdtype) \
+            .writeUint32(self.type.value) \
             .data
 
     def __str__(self):
         return 'Ping: ' + "\n" \
-            + "\t" + 'cmdtype: ' + str(self.cmdtype) + "\n" \
+            + "\t" + 'type: ' + str(self.type) + "\n" \
             + "\t" + 'data: ' + str(self.data) + "\n"
